@@ -1,5 +1,5 @@
-#ifndef GALLERY_H
-#define GALLERY_H
+#ifndef LIBRARYMODEL_H
+#define LIBRARYMODEL_H
 
 #include <QObject>
 
@@ -18,27 +18,19 @@ class LibraryModel : public MauiList
 public:
     explicit LibraryModel(QObject *parent = nullptr);
     const FMH::MODEL_LIST &items() const override;
+    void componentComplete() override final;
 
 private:
     FMH::FileLoader *m_fileLoader;
     FMH::MODEL_LIST list;  
 
-    bool addDoc(const FMH::MODEL &doc);
-    void refreshCollection();
+    void setList();
 
-public slots:    
-    bool update(const int &index, const QVariant &value, const int &role); //deprecrated
-    bool update(const QVariantMap &data, const int &index);
-    bool update(const FMH::MODEL &pic);
+public slots:
     bool remove(const int &index);
     bool deleteAt(const int &index);
-    bool fav(const int &index, const bool &value);
     bool bookmark(const int &index, const int &value);
-    void append(const QVariantMap &pic);
-    void append(const QString &url);
     void clear();
-
-    void insert(const QString &url);
 };
 
-#endif // GALLERY_H
+#endif // LIBRARYMODEL_H
